@@ -8,6 +8,9 @@ SENTENCE_BREAK = '(...)'
 GLOBAL = '!global'
 REGEX_SPECIAL_CHARS = r'\.|()[]{}^$*+?-'
 
+_REGEX_SPECIAL_CHARS = REGEX_SPECIAL_CHARS + ';~'
+_REGEX_SPECIAL_CHARS_RE = re.compile('|'.join('\\' + c for c in _REGEX_SPECIAL_CHARS))
+
 WORD_BOUNDARY, WORD_BOUNDARY_CHAR = r'\b', '~'
 PURE_WORD_BOUNDARY_RE = re.compile(r'^[\s~]*$')
 
@@ -52,8 +55,30 @@ class SearchString(Generic[Data]):
     >>> arla_ss2.highlight('A text about Arla')
     'A text about <b>Arla</b>'
     """
-    def __init__(self, first_str: str, second_str: str, not_str: str,
-                 *, data: Data, third_str: Optional[str] = None):
+    __slots__ = (
+        'data',
+        'first_str',
+        'first_str_global',
+        'second_str',
+        'second_str_global',
+        'show_third_in_repr',
+        'third_str',
+        'third_str_global',
+        'not_str',
+        'not_str_global',
+        'matched_sentences',
+        '_any_global',
+    )
+
+    def __init__(
+        self,
+        first_str: str,
+        second_str: str,
+        not_str: str,
+        *,
+        data: Data,
+        third_str: Optional[str] = None
+    ) -> None:
         self.data = data
 
         search_str, first_str_global = self._preprocess_string(first_str)
@@ -74,7 +99,7 @@ class SearchString(Generic[Data]):
         self.not_str_global = not_str_global
 
         self.matched_sentences: List[str] = []
-        self.any_global = any([
+        self._any_global = any([
             first_str_global,
             second_str_global,
             third_str_global,
@@ -116,7 +141,7 @@ class SearchString(Generic[Data]):
         """Reset the matched sentences list to an empty list"""
         self.matched_sentences = []
 
-    def _preprocess_string(self, string: str) -> Tuple[Optional[re.Pattern], bool]:
+    def _preprocess_string(self, string: str) -> Tuple[Union[None, re.Pattern, str], bool]:
         """
         Preprocesses a single string into a list of patterns.
 
@@ -142,20 +167,35 @@ class SearchString(Generic[Data]):
             cleaned = cleaned[:-len(GLOBAL)]
             is_global = True
 
-        parts = cleaned.rstrip(';').split(';')
+        final_str = cleaned.rstrip(';')
+        if not final_str:
+            return None, is_global
+
+        parts = final_str.split(';')
         full_pattern = '|'.join(filter(None, map(self._escape_pattern, parts)))
         if not full_pattern:
             return None, is_global
 
+        # if not any(char in final_str for char in _REGEX_SPECIAL_CHARS):
+        if not _REGEX_SPECIAL_CHARS_RE.search(final_str):
+            return final_str, is_global
+
         return re.compile(full_pattern, flags=re.IGNORECASE), is_global
 
-    def _any_match(self, text: str, re_pattern: Optional[re.Pattern],
+    def _any_match(self, text: str, re_pattern: Union[re.Pattern, None, str],
                    empty_ret: bool = True) -> bool:
         """
         Returns a bool indicating whether the pattern matches the text.
         In case the pattern is empty, the empty_ret value is returned.
         """
-        return bool(re_pattern.search(text)) if re_pattern else empty_ret
+        if not re_pattern:
+            return empty_ret
+
+        return (
+            re_pattern in text.lower()
+            if isinstance(re_pattern, str)
+            else bool(re_pattern.search(text))
+        )
 
     def _match_sentence(self, sentence: str) -> bool:
         """
@@ -206,7 +246,7 @@ class SearchString(Generic[Data]):
         fst_global, snd_global, third_global, not_global \
             = False, False, False, False
 
-        if self.any_global:
+        if self._any_global:
             full_text = '\n\n'.join(sentences)
             if self.first_str_global:
                 fst_global = self._any_match(full_text, self.first_str)
@@ -282,13 +322,18 @@ class SearchString(Generic[Data]):
         try:
             subbed = text
             for re_pattern in [self.first_str, self.second_str, self.third_str]:
-                if re_pattern:
+                if re_pattern is None:
+                    continue
+                elif isinstance(re_pattern, str):
+                    subbed = re.sub(re_pattern, r'<b>\g<0></b>', subbed, flags=re.IGNORECASE)
+                else:
                     subbed = re_pattern.sub(r'<b>\g<0></b>', subbed)
+
             return subbed
         except Exception:
             return text
 
-    def _pattern_to_str(self, re_pattern: Optional[re.Pattern],
+    def _pattern_to_str(self, re_pattern: Union[None, re.Pattern, str],
                         is_global: bool) -> str:
         """
         Returns a string representation of the list of patterns for one of the
@@ -297,6 +342,9 @@ class SearchString(Generic[Data]):
         if re_pattern is None:
             return '-'
 
+        if isinstance(re_pattern, str):
+            return re_pattern
+
         replaced = re_pattern.pattern\
             .replace('|', ';')\
             .replace(WORD_BOUNDARY, WORD_BOUNDARY_CHAR)\
